@@ -48,11 +48,17 @@ class WlanDriverStatusPlugin(StatusMenuItem):
 			file = '/sbin/load-bleeding-edge-drivers.sh'
 		else:
 			file = '/sbin/unload-bleeding-edge-drivers.sh'
-		output = commands.getoutput('cd '+folder+'; sudo sh '+file)
+		output = commands.getoutput('cd '+folder+'; sudo '+file)
 		if driver:
-			self.Notifications.notify('Loaded Bleeding Edge drivers')
+			if len(output)>0:
+				self.Notifications.notify('Error while loading Bleeding Edge drivers:\n'+output)
+			else:
+				self.Notifications.notify('Loaded Bleeding Edge drivers')
 		else:
-			self.Notifications.notify('Loaded Stock drivers')
+			if len(output)>0:
+				self.Notifications.notify('Error while loading Stock drivers:\n'+output)
+			else:
+				self.Notifications.notify('Loaded Stock drivers')
 		self.status = driver
 
 	def updateButton(self):
